==> microfrontends-0.0.3.tar.gz: lib/src/state_container.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:microfrontends/src/container_slot.dart';
import 'package:microfrontends/src/state_container_context.dart';

import 'context.dart';
import 'mutation.dart';
import 'query.dart';
import 'resolver.dart';
import 'extensions.dart';

abstract class StateContainer<T> {
  final ValueNotifier<T> stateNotifier;

  late final queryResolvers = Context<Type, QueryResolver>({});
  final mutationResolvers = Context<Type, MutationResolver>();

  T get state {
    return stateNotifier.value;
  }

  set state(T state) {
    stateNotifier.value = state;
  }

  Type get stateType => T;

  ResolverController<T> get resolverController =>
      ResolverController(stateNotifier);

  static StateContainer<T> of<T>(BuildContext context) =>
      context.getContainerOfType<T>();

  StateContainer(T state) : stateNotifier = ValueNotifier(state);

  Stream<T> boot(StateContainerContext context) async* {}

  @mustCallSuper
  queries(StateContainerContext context) {
    query((ctrl, value, arg) => value);
  }

  @mustCallSuper
  mutations(StateContainerContext context) {
    mutation<SetState<T>>((ctrl, value, arg) => arg!.payload);
  }

  @mustCallSuper
  shutDown() {}

  void query<K>(ResolverCallback<K, T, Object?> callback) {
    final queryResolver = QueryResolver<T, K>(resolverController, callback);
    queryResolvers[queryResolver.keyType] = queryResolver;
  }

  void mutation<K extends Mutation>(ResolverCallback<T, T, K> callback) {
    final mutationResolver =
        MutationResolver<K, T>(resolverController, callback);
    mutationResolvers[K] = mutationResolver;
  }

  StateContainer<T> fork() {
    return StateContainerFork<T>(this);
  }

  mount({Key? key, required Widget child}) {
    return StateContainerSlot(
      key: key,
      container: this,
      child: child,
    );
  }
}

class StateContainerFork<T> extends StateContainer<T> {
  StateContainerFork(StateContainer<T> master) : super(master.state) {
    queryResolvers.addAll(master.queryResolvers);
    mutationResolvers.addAll(master.mutationResolvers);
  }
}

==> microfrontends-0.0.4.tar.gz: lib/src/state_container.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:microfrontends/src/container_slot.dart';
import 'package:microfrontends/src/state_container_context.dart';

import 'context.dart';
import 'mutation.dart';
import 'query.dart';
import 'resolver.dart';
import 'extensions.dart';

abstract class StateContainer<T> {
  final ValueNotifier<T> stateNotifier;

  late final queryResolvers = Context<Type, QueryResolver>({});
  final mutationResolvers = Context<Type, MutationResolver>();

  T get state {
    return stateNotifier.value;
  }

  set state(T state) {
    stateNotifier.value = state;
  }

  Type get stateType => T;

  ResolverController<T> get resolverController =>
      ResolverController(stateNotifier);

  static StateContainer<T> of<T>(BuildContext context) =>
      context.getContainerOfType<T>();

  StateContainer(T state) : stateNotifier = ValueNotifier(state);

  Stream<T> boot(StateContainerContext context) async* {}

  @mustCallSuper
  queries(StateContainerContext context) {
    query((ctrl, value, arg) => value);
  }

  @mustCallSuper
  mutations(StateContainerContext context) {
    mutation<SetState<T>>((ctrl, value, arg) => arg!.payload);
  }

  @mustCallSuper
  shutDown() {}

  void query<K>(ResolverCallback<K, T, Object?> callback) {
    final queryResolver = QueryResolver<T, K>(resolverController, callback);
    queryResolvers[queryResolver.keyType] = queryResolver;
  }

  void mutation<K extends Mutation>(ResolverCallback<T, T, K> callback) {
    final mutationResolver =
        MutationResolver<K, T>(resolverController, callback);
    mutationResolvers[K] = mutationResolver;
  }

  StateContainer<T> fork() {
    return StateContainerFork<T>(this);
  }

  mount({Key? key, Widget? child, WidgetBuilder? builder}) {
    assert(child == null ? builder != null : true);
    child ??= Builder(builder: builder!);

    return StateContainerSlot(
      key: key,
      container: this,
      child: child,
    );
  }
}

class StateContainerFork<T> extends StateContainer<T> {
  StateContainerFork(StateContainer<T> master) : super(master.state) {
    queryResolvers.addAll(master.queryResolvers);
    mutationResolvers.addAll(master.mutationResolvers);
  }
}
